use crate::consts::HIGHLIGHT_COLOR;
use std::fmt::Display;
use tui::buffer::Buffer;
use tui::layout::Rect;
use tui::style::*;
use tui::widgets::*;

pub struct CheckboxWidget {
    is_editing: bool,
    checked: bool,
    label: String,
    is_radio: bool,
}

impl CheckboxWidget {
    pub fn new<D: Display>(label: D, checked: bool, is_editing: bool) -> Self {
        Self {
            is_editing,
            checked,
            label: label.to_string(),
            is_radio: false,
        }
    }

    pub fn set_radio(mut self) -> Self {
        self.is_radio = true;
        self
    }
}

impl Widget for CheckboxWidget {
    fn render(self, area: Rect, buf: &mut Buffer) {
        let paragraph = format!(
            "{}{}{} {}",
            match self.is_radio {
                true => "(",
                false => "[",
            },
            match self.checked {
                true => "X",
                false => " ",
            },
            match self.is_radio {
                true => ")",
                false => "]",
            },
            self.label
        );

        let input = Paragraph::new(paragraph.as_ref()).style(match &self.is_editing {
            false => Style::default(),
            true => Style::default().fg(HIGHLIGHT_COLOR),
        });

        input.render(area, buf);
    }
}
